import { useForm } from "react-hook-form";
import { zodResolver } from "@hookform/resolvers/zod";
import { useMutation } from "@tanstack/react-query";
import { insertLeadSchema, type InsertLead } from "@shared/schema";
import { apiRequest } from "@/lib/queryClient";
import { useToast } from "@/hooks/use-toast";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select";
import { Form, FormControl, FormField, FormItem, FormMessage } from "@/components/ui/form";
import { trackLeadSubmission } from "./tracking";

export default function Hero() {
  const { toast } = useToast();
  
  const form = useForm<InsertLead>({
    resolver: zodResolver(insertLeadSchema),
    defaultValues: {
      name: "",
      practice: "",
      email: "",
      phone: "",
      location: "",
      practiceType: "",
      emr: "",
      physicians: undefined,
      revenue: "",
      connectionPreference: "",
      contactPreference: "",
      billingCompanyPreference: "",
    },
  });

  const submitLeadMutation = useMutation({
    mutationFn: async (data: InsertLead) => {
      return await apiRequest("/api/leads", "POST", data);
    },
    onSuccess: () => {
      trackLeadSubmission(form.getValues());
      toast({
        title: "Success!",
        description: "Your request has been submitted. We'll contact you soon!",
      });
      form.reset();
    },
    onError: (error: any) => {
      toast({
        title: "Error",
        description: error.message || "Something went wrong. Please try again.",
        variant: "destructive",
      });
    },
  });

  const onSubmit = (data: InsertLead) => {
    submitLeadMutation.mutate(data);
  };

  return (
    <div>
      <section id="hero" className="bg-trust-light-blue py-16 lg:py-20" itemScope itemType="https://schema.org/Service">
        <div className="container mx-auto px-4 max-w-6xl text-center">
          <div className="mb-8 flex justify-center">
            <img 
              src="/logo.png" 
              alt="TRUST Billing Connect" 
              className="h-48 w-auto"
            />
          </div>
          
          <h1 className="text-3xl md:text-4xl lg:text-5xl font-bold mb-6 text-gray-800" itemProp="name">
            Connect with Your Perfect Medical Billing Partner Today!
          </h1>
          
          <p className="text-lg md:text-xl mb-8 text-gray-700 max-w-4xl mx-auto" itemProp="description">
            Connect with trusted medical billing companies and revenue cycle management experts. Increase your healthcare practice's cash flow by up to 35% with professional medical billing services, claims processing, and practice management solutions.
          </p>
        
        {/* Lead Generation Form */}
        <div className="max-w-4xl mx-auto">
          <Form {...form}>
            <form
              onSubmit={form.handleSubmit(onSubmit)}
              className="bg-white p-6 lg:p-8 rounded-lg shadow-lg"
            >
              <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-4">
                <FormField
                  control={form.control}
                  name="name"
                  render={({ field }) => (
                    <FormItem>
                      <FormControl>
                        <Input
                          placeholder="Full Name"
                          {...field}
                          className="px-4 py-3 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={form.control}
                  name="practice"
                  render={({ field }) => (
                    <FormItem>
                      <FormControl>
                        <Input
                          placeholder="Practice Name"
                          {...field}
                          className="px-4 py-3 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={form.control}
                  name="email"
                  render={({ field }) => (
                    <FormItem>
                      <FormControl>
                        <Input
                          type="email"
                          placeholder="Email Address"
                          {...field}
                          className="px-4 py-3 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={form.control}
                  name="phone"
                  render={({ field }) => (
                    <FormItem>
                      <FormControl>
                        <Input
                          type="tel"
                          placeholder="Phone Number"
                          {...field}
                          className="px-4 py-3 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={form.control}
                  name="location"
                  render={({ field }) => (
                    <FormItem>
                      <FormControl>
                        <Input
                          placeholder="Practice Location"
                          {...field}
                          value={field.value ?? ""}
                          className="px-4 py-3 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={form.control}
                  name="practiceType"
                  render={({ field }) => (
                    <FormItem>
                      <Select onValueChange={field.onChange} value={field.value || ""}>
                        <FormControl>
                          <SelectTrigger className="px-4 py-3 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent">
                            <SelectValue placeholder="Select Practice Type" />
                          </SelectTrigger>
                        </FormControl>
                        <SelectContent>
                          <SelectItem value="Chiropractic">Chiropractic</SelectItem>
                          <SelectItem value="Dental">Dental</SelectItem>
                          <SelectItem value="Hospital">Hospital</SelectItem>
                          <SelectItem value="Other">Other</SelectItem>
                          <SelectItem value="Primary care">Primary care</SelectItem>
                          <SelectItem value="Mental health">Mental health</SelectItem>
                          <SelectItem value="Specialty">Specialty</SelectItem>
                        </SelectContent>
                      </Select>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={form.control}
                  name="emr"
                  render={({ field }) => (
                    <FormItem>
                      <FormControl>
                        <Input
                          placeholder="Current EMR Software"
                          {...field}
                          value={field.value ?? ""}
                          className="px-4 py-3 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={form.control}
                  name="physicians"
                  render={({ field }) => (
                    <FormItem>
                      <FormControl>
                        <Input
                          type="number"
                          placeholder="Num of Physicians"
                          {...field}
                          onChange={(e) => field.onChange(e.target.value ? parseInt(e.target.value) : undefined)}
                          value={field.value ?? ""}
                          className="px-4 py-3 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={form.control}
                  name="revenue"
                  render={({ field }) => (
                    <FormItem>
                      <Select onValueChange={field.onChange} value={field.value || ""}>
                        <FormControl>
                          <SelectTrigger className="px-4 py-3 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent">
                            <SelectValue placeholder="Monthly Revenue Range" />
                          </SelectTrigger>
                        </FormControl>
                        <SelectContent>
                          <SelectItem value="$0–$50K">$0–$50K</SelectItem>
                          <SelectItem value="$50K–$100K">$50K–$100K</SelectItem>
                          <SelectItem value="$100K+">$100K+</SelectItem>
                        </SelectContent>
                      </Select>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                {/* Preferred Matching Choice Section */}
                <div className="col-span-full bg-gradient-to-r from-blue-50 to-indigo-50 p-6 rounded-lg border-2 border-blue-200">
                  <h3 className="text-xl font-bold text-gray-800 mb-3 text-center">
                    Preferred Matching Choice
                  </h3>
                  <p className="text-sm text-gray-600 mb-4 text-center">
                    Would you prefer exclusive matching with one billing company or shared matching with multiple companies?
                  </p>
                  
                  <FormField
                    control={form.control}
                    name="connectionPreference"
                    render={({ field }) => (
                      <FormItem>
                        <Select onValueChange={field.onChange} value={field.value || ""}>
                          <FormControl>
                            <SelectTrigger className="px-4 py-3 border-2 border-blue-400 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-600 focus:border-blue-600 bg-white text-base font-medium">
                              <SelectValue placeholder="Choose your matching preference" />
                            </SelectTrigger>
                          </FormControl>
                          <SelectContent>
                            <SelectItem value="Exclusive matching with one billing company" className="py-3">
                              <div className="flex items-center space-x-2">
                                <span className="text-lg">🔒</span>
                                <div>
                                  <div className="font-semibold">Exclusive Matching</div>
                                  <div className="text-sm text-gray-600">Connect with ONE billing company only</div>
                                </div>
                              </div>
                            </SelectItem>
                            <SelectItem value="Shared matching with multiple billing companies" className="py-3">
                              <div className="flex items-center space-x-2">
                                <span className="text-lg">🤝</span>
                                <div>
                                  <div className="font-semibold">Shared Matching</div>
                                  <div className="text-sm text-gray-600">Connect with MULTIPLE companies (up to 5)</div>
                                </div>
                              </div>
                            </SelectItem>
                          </SelectContent>
                        </Select>
                        <FormMessage />
                      </FormItem>
                    )}
                  />
                </div>
              </div>
              
              <Button
                type="submit"
                disabled={submitLeadMutation.isPending}
                className="w-full sm:w-auto mt-6 px-8 py-3 bg-trust-blue text-white font-bold rounded-md hover:bg-blue-700 transition-colors focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2"
              >
                {submitLeadMutation.isPending ? "Submitting..." : "Find My Billing Partner"}
              </Button>
            </form>
          </Form>
        </div>
      </div>
    </section>
    </div>
  );
}
